@@ -1023,11 +1023,10 @@ cached: list[str] = [
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-scraper.json",
     "aws-aps-workspace.json",
+    "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
-    "aws-athena-namedquery.json",
-    "aws-athena-preparedstatement.json",
     "aws-athena-workgroup.json",
     "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
@@ -1145,7 +1144,6 @@ cached: list[str] = [
     "aws-connect-contactflow.json",
     "aws-connect-contactflowmodule.json",
     "aws-connect-contactflowversion.json",
-    "aws-connect-emailaddress.json",
     "aws-connect-evaluationform.json",
     "aws-connect-hoursofoperation.json",
     "aws-connect-instance.json",
@@ -1374,7 +1372,6 @@ cached: list[str] = [
     "aws-events-archive.json",
     "aws-events-connection.json",
     "aws-events-eventbus.json",
-    "aws-events-eventbuspolicy.json",
     "aws-events-rule.json",
     "aws-eventschemas-discoverer.json",
     "aws-eventschemas-registry.json",
@@ -1479,6 +1476,7 @@ cached: list[str] = [
     "aws-lambda-codesigningconfig.json",
     "aws-lambda-eventinvokeconfig.json",
     "aws-lambda-eventsourcemapping.json",
+    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
     "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
@@ -1491,13 +1489,16 @@ cached: list[str] = [
     "aws-lex-resourcepolicy.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
+    "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
     "aws-logs-loganomalydetector.json",
     "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
+    "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
+    "aws-logs-subscriptionfilter.json",
     "aws-logs-transformer.json",
     "aws-m2-application.json",
     "aws-m2-deployment.json",
@@ -1639,7 +1640,6 @@ cached: list[str] = [
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
-    "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
@@ -1675,7 +1675,6 @@ cached: list[str] = [
     "aws-sagemaker-pipeline.json",
     "aws-sagemaker-processingjob.json",
     "aws-sagemaker-project.json",
-    "aws-sagemaker-space.json",
     "aws-sagemaker-studiolifecycleconfig.json",
     "aws-sagemaker-userprofile.json",
     "aws-sagemaker-workteam.json",
@@ -1709,6 +1708,7 @@ cached: list[str] = [
     "aws-servicecatalog-serviceactionassociation.json",
     "aws-servicecatalog-stacksetconstraint.json",
     "aws-servicecatalog-tagoption.json",
+    "aws-servicecatalog-tagoptionassociation.json",
     "aws-servicecatalogappregistry-application.json",
     "aws-servicecatalogappregistry-attributegroup.json",
     "aws-servicecatalogappregistry-attributegroupassociation.json",
@@ -1772,7 +1772,6 @@ cached: list[str] = [
     "aws-transfer-certificate.json",
     "aws-transfer-connector.json",
     "aws-transfer-profile.json",
-    "aws-transfer-server.json",
     "aws-transfer-user.json",
     "aws-transfer-webapp.json",
     "aws-transfer-workflow.json",
