@@ -161,6 +161,8 @@ types: list[str] = [
     "AWS::Bedrock::PromptVersion",
     "AWS::BedrockAgentCore::BrowserCustom",
     "AWS::BedrockAgentCore::CodeInterpreterCustom",
+    "AWS::BedrockAgentCore::Gateway",
+    "AWS::BedrockAgentCore::GatewayTarget",
     "AWS::BedrockAgentCore::Memory",
     "AWS::BedrockAgentCore::Runtime",
     "AWS::BedrockAgentCore::RuntimeEndpoint",
@@ -368,6 +370,7 @@ types: list[str] = [
     "AWS::DocDBElastic::Cluster",
     "AWS::DynamoDB::GlobalTable",
     "AWS::DynamoDB::Table",
+    "AWS::EC2::CapacityManagerDataExport",
     "AWS::EC2::CapacityReservation",
     "AWS::EC2::CapacityReservationFleet",
     "AWS::EC2::ClientVpnAuthorizationRule",
@@ -1112,6 +1115,7 @@ types: list[str] = [
     "AWS::SSMIncidents::ReplicationSet",
     "AWS::SSMIncidents::ResponsePlan",
     "AWS::SSMQuickSetup::ConfigurationManager",
+    "AWS::SSMQuickSetup::LifecycleAutomation",
     "AWS::SSO::Application",
     "AWS::SSO::ApplicationAssignment",
     "AWS::SSO::Assignment",
@@ -1432,6 +1436,7 @@ cached: list[str] = [
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
+    "aws-bedrock-agent.json",
     "aws-bedrock-agentalias.json",
     "aws-bedrock-applicationinferenceprofile.json",
     "aws-bedrock-blueprint.json",
@@ -1440,7 +1445,6 @@ cached: list[str] = [
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
-    "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
     "aws-bedrock-intelligentpromptrouter.json",
     "aws-bedrock-knowledgebase.json",
@@ -1448,8 +1452,9 @@ cached: list[str] = [
     "aws-bedrock-promptversion.json",
     "aws-bedrockagentcore-browsercustom.json",
     "aws-bedrockagentcore-codeinterpretercustom.json",
+    "aws-bedrockagentcore-gateway.json",
+    "aws-bedrockagentcore-gatewaytarget.json",
     "aws-bedrockagentcore-memory.json",
-    "aws-bedrockagentcore-runtime.json",
     "aws-bedrockagentcore-runtimeendpoint.json",
     "aws-budgets-budget.json",
     "aws-budgets-budgetsaction.json",
@@ -1644,6 +1649,7 @@ cached: list[str] = [
     "aws-dms-replicationinstance.json",
     "aws-dms-replicationsubnetgroup.json",
     "aws-dms-replicationtask.json",
+    "aws-docdb-dbcluster.json",
     "aws-docdb-dbclusterparametergroup.json",
     "aws-docdb-dbinstance.json",
     "aws-docdb-dbsubnetgroup.json",
@@ -1651,6 +1657,7 @@ cached: list[str] = [
     "aws-docdbelastic-cluster.json",
     "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
+    "aws-ec2-capacitymanagerdataexport.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-clientvpnauthorizationrule.json",
@@ -1829,7 +1836,6 @@ cached: list[str] = [
     "aws-forecast-dataset.json",
     "aws-forecast-datasetgroup.json",
     "aws-fsx-datarepositoryassociation.json",
-    "aws-fsx-filesystem.json",
     "aws-fsx-snapshot.json",
     "aws-fsx-storagevirtualmachine.json",
     "aws-fsx-volume.json",
@@ -2056,14 +2062,17 @@ cached: list[str] = [
     "aws-location-trackerconsumer.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
+    "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
     "aws-logs-integration.json",
     "aws-logs-loganomalydetector.json",
     "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
+    "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
+    "aws-logs-subscriptionfilter.json",
     "aws-logs-transformer.json",
     "aws-m2-application.json",
     "aws-m2-deployment.json",
@@ -2137,10 +2146,7 @@ cached: list[str] = [
     "aws-neptune-eventsubscription.json",
     "aws-neptunegraph-graph.json",
     "aws-neptunegraph-privategraphendpoint.json",
-    "aws-networkfirewall-firewall.json",
-    "aws-networkfirewall-firewallpolicy.json",
     "aws-networkfirewall-loggingconfiguration.json",
-    "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-networkfirewall-vpcendpointassociation.json",
     "aws-networkmanager-connectpeer.json",
@@ -2178,7 +2184,6 @@ cached: list[str] = [
     "aws-organizations-organizationalunit.json",
     "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
-    "aws-osis-pipeline.json",
     "aws-paymentcryptography-alias.json",
     "aws-paymentcryptography-key.json",
     "aws-pcaconnectorad-connector.json",
@@ -2349,7 +2354,6 @@ cached: list[str] = [
     "aws-sagemaker-pipeline.json",
     "aws-sagemaker-processingjob.json",
     "aws-sagemaker-project.json",
-    "aws-sagemaker-space.json",
     "aws-sagemaker-studiolifecycleconfig.json",
     "aws-sagemaker-userprofile.json",
     "aws-sagemaker-workteam.json",
@@ -2457,6 +2461,7 @@ cached: list[str] = [
     "aws-ssmincidents-replicationset.json",
     "aws-ssmincidents-responseplan.json",
     "aws-ssmquicksetup-configurationmanager.json",
+    "aws-ssmquicksetup-lifecycleautomation.json",
     "aws-sso-application.json",
     "aws-sso-applicationassignment.json",
     "aws-sso-assignment.json",
