@@ -987,6 +987,7 @@ cached: list[str] = [
     "aws-ec2-securitygroupvpcassociation.json",
     "aws-ec2-snapshotblockpublicaccess.json",
     "aws-ec2-spotfleet.json",
+    "aws-ec2-subnet.json",
     "aws-ec2-subnetcidrblock.json",
     "aws-ec2-subnetnetworkaclassociation.json",
     "aws-ec2-subnetroutetableassociation.json",
@@ -1030,7 +1031,9 @@ cached: list[str] = [
     "aws-ecr-repositorycreationtemplate.json",
     "aws-ecs-capacityprovider.json",
     "aws-ecs-cluster.json",
+    "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
+    "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
@@ -1247,12 +1250,15 @@ cached: list[str] = [
     "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-logs-delivery.json",
+    "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
     "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
+    "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
+    "aws-logs-subscriptionfilter.json",
     "aws-memorydb-acl.json",
     "aws-memorydb-cluster.json",
     "aws-memorydb-parametergroup.json",
@@ -1411,6 +1417,7 @@ cached: list[str] = [
     "aws-securityhub-standard.json",
     "aws-servicecatalog-cloudformationproduct.json",
     "aws-servicecatalog-cloudformationprovisionedproduct.json",
+    "aws-servicecatalog-launchnotificationconstraint.json",
     "aws-servicecatalog-launchroleconstraint.json",
     "aws-servicecatalog-launchtemplateconstraint.json",
     "aws-servicecatalog-portfolioproductassociation.json",
@@ -1418,6 +1425,7 @@ cached: list[str] = [
     "aws-servicecatalog-resourceupdateconstraint.json",
     "aws-servicecatalog-stacksetconstraint.json",
     "aws-servicecatalog-tagoption.json",
+    "aws-servicecatalog-tagoptionassociation.json",
     "aws-servicediscovery-httpnamespace.json",
     "aws-servicediscovery-instance.json",
     "aws-servicediscovery-privatednsnamespace.json",
