@@ -6,6 +6,7 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthority",
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
+    "AWS::APS::AnomalyDetector",
     "AWS::APS::ResourcePolicy",
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
@@ -396,6 +397,7 @@ types: list[str] = [
     "AWS::DocDBElastic::Cluster",
     "AWS::DynamoDB::GlobalTable",
     "AWS::DynamoDB::Table",
+    "AWS::EC2::CapacityManagerDataExport",
     "AWS::EC2::CapacityReservation",
     "AWS::EC2::CapacityReservationFleet",
     "AWS::EC2::CarrierGateway",
@@ -930,6 +932,8 @@ types: list[str] = [
     "AWS::PCS::Cluster",
     "AWS::PCS::ComputeNodeGroup",
     "AWS::PCS::Queue",
+    "AWS::PaymentCryptography::Alias",
+    "AWS::PaymentCryptography::Key",
     "AWS::Pinpoint::ADMChannel",
     "AWS::Pinpoint::APNSChannel",
     "AWS::Pinpoint::APNSSandboxChannel",
@@ -1107,6 +1111,7 @@ types: list[str] = [
     "AWS::SSMIncidents::ReplicationSet",
     "AWS::SSMIncidents::ResponsePlan",
     "AWS::SSMQuickSetup::ConfigurationManager",
+    "AWS::SSMQuickSetup::LifecycleAutomation",
     "AWS::SSO::Application",
     "AWS::SSO::ApplicationAssignment",
     "AWS::SSO::Assignment",
@@ -1328,11 +1333,9 @@ cached: list[str] = [
     "aws-apigateway-domainname.json",
     "aws-apigateway-domainnamev2.json",
     "aws-apigateway-gatewayresponse.json",
-    "aws-apigateway-method.json",
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
-    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -1405,6 +1408,7 @@ cached: list[str] = [
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
+    "aws-aps-anomalydetector.json",
     "aws-aps-resourcepolicy.json",
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-scraper.json",
@@ -1440,6 +1444,7 @@ cached: list[str] = [
     "aws-batch-schedulingpolicy.json",
     "aws-batch-serviceenvironment.json",
     "aws-bcmdataexports-export.json",
+    "aws-bedrock-agent.json",
     "aws-bedrock-agentalias.json",
     "aws-bedrock-applicationinferenceprofile.json",
     "aws-bedrock-blueprint.json",
@@ -1628,13 +1633,9 @@ cached: list[str] = [
     "aws-datasync-locations3.json",
     "aws-datasync-locationsmb.json",
     "aws-datasync-task.json",
-    "aws-datazone-connection.json",
-    "aws-datazone-datasource.json",
-    "aws-datazone-domain.json",
     "aws-datazone-domainunit.json",
     "aws-datazone-environment.json",
     "aws-datazone-environmentactions.json",
-    "aws-datazone-environmentblueprintconfiguration.json",
     "aws-datazone-environmentprofile.json",
     "aws-datazone-formtype.json",
     "aws-datazone-groupprofile.json",
@@ -1687,6 +1688,7 @@ cached: list[str] = [
     "aws-dsql-cluster.json",
     "aws-dynamodb-globaltable.json",
     "aws-dynamodb-table.json",
+    "aws-ec2-capacitymanagerdataexport.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-carriergateway.json",
@@ -2072,14 +2074,17 @@ cached: list[str] = [
     "aws-location-trackerconsumer.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
+    "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
     "aws-logs-destination.json",
     "aws-logs-integration.json",
     "aws-logs-loganomalydetector.json",
     "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
+    "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
     "aws-logs-resourcepolicy.json",
+    "aws-logs-subscriptionfilter.json",
     "aws-logs-transformer.json",
     "aws-m2-application.json",
     "aws-m2-deployment.json",
@@ -2196,7 +2201,8 @@ cached: list[str] = [
     "aws-organizations-organizationalunit.json",
     "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
-    "aws-osis-pipeline.json",
+    "aws-paymentcryptography-alias.json",
+    "aws-paymentcryptography-key.json",
     "aws-pcaconnectorad-connector.json",
     "aws-pcaconnectorad-directoryregistration.json",
     "aws-pcaconnectorad-serviceprincipalname.json",
@@ -2204,6 +2210,7 @@ cached: list[str] = [
     "aws-pcaconnectorad-templategroupaccesscontrolentry.json",
     "aws-pcaconnectorscep-challenge.json",
     "aws-pcaconnectorscep-connector.json",
+    "aws-pcs-cluster.json",
     "aws-pcs-computenodegroup.json",
     "aws-pcs-queue.json",
     "aws-pinpoint-apnschannel.json",
@@ -2310,7 +2317,6 @@ cached: list[str] = [
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
-    "aws-s3-accessgrantslocation.json",
     "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
@@ -2356,7 +2362,6 @@ cached: list[str] = [
     "aws-sagemaker-pipeline.json",
     "aws-sagemaker-processingjob.json",
     "aws-sagemaker-project.json",
-    "aws-sagemaker-space.json",
     "aws-sagemaker-studiolifecycleconfig.json",
     "aws-sagemaker-userprofile.json",
     "aws-sagemaker-workteam.json",
@@ -2464,6 +2469,7 @@ cached: list[str] = [
     "aws-ssmincidents-replicationset.json",
     "aws-ssmincidents-responseplan.json",
     "aws-ssmquicksetup-configurationmanager.json",
+    "aws-ssmquicksetup-lifecycleautomation.json",
     "aws-sso-application.json",
     "aws-sso-applicationassignment.json",
     "aws-sso-assignment.json",
